==> core-android-debug-1.12.3-sources.jar: commonMain/io/dyte/core/models/DyteRoomParticipants.kt <==
package io.dyte.core.models

import io.dyte.core.controllers.IControllerContainer
import io.dyte.core.feat.DyteMeetingParticipant

/**
 * Dyte room participants
 *
 * @property waitlisted A map that contains all the participants waiting to join the meeting.
 * @property joined A list that contains all the participants who have joined the meeting.
 * @property active A map that contains all the participants except the local user who are supposed to be on the screen at the moment
 * @property pinned A map that contains all the pinned participants of the meeting
 *
 * @constructor Create empty Dyte room participants
 */
data class DyteRoomParticipants internal constructor(
  val waitlisted: List<DyteMeetingParticipant>,
  val joined: List<DyteMeetingParticipant>,
  val active: List<DyteMeetingParticipant>,
  val screenshares: List<DyteMeetingParticipant>,
  private val controllerContainer: IControllerContainer
) {

  val pinned: DyteMeetingParticipant?
    get() = controllerContainer.participantController.pinnedParticipant

  val activeSpeaker: DyteMeetingParticipant?
    get() = controllerContainer.participantController.activeSpeaker

  val currentPageNumber : Int
    get() = controllerContainer.participantController.getGridInfo().currentPageNumber

  val canGoNextPage : Boolean
    get() = controllerContainer.participantController.getGridInfo().isNextPagePossible

  val canGoPreviousPage : Boolean
    get() = controllerContainer.participantController.getGridInfo().isPreviousPagePossible

  val pageCount: Int
    get() = controllerContainer.participantController.getGridInfo().pageCount

  fun toMap(): Map<String, Any?> {
    val map = HashMap<String, Any?>()
    map["waitlisted"] = listDyteMeetingParticipantToMap(waitlisted)
    map["joined"] = listDyteMeetingParticipantToMap(joined)
    map["active"] = listDyteMeetingParticipantToMap(active)
    map["pinned"] = pinned?.toMap()
    map["activeSpeaker"] = activeSpeaker?.toMap()
    map["grid"] = controllerContainer.participantController.getGridInfo().toMap()
    return map
  }

  private fun listDyteMeetingParticipantToMap(participants: List<DyteMeetingParticipant>): List<Map<String, Any?>> {
    return participants.map { it.toMap() }
  }

  @Throws(Exception::class)
  fun setPage(pageNumber: Int) {
    if (pageNumber < 0) {
      throw IllegalArgumentException("page number cant be negative")
    }
    controllerContainer.participantController.setPage(pageNumber)
  }

  fun disableAllAudio() {
    // TODO : fix this hardcoding
    controllerContainer.hostController.muteAllAudio(true)
  }

  @Throws(Exception::class)
  fun disableAllVideo() {
    controllerContainer.hostController.muteAllVideo()
  }

  @Throws(Exception::class)
  fun acceptAllWaitingRequests() {
    controllerContainer.waitlistController.acceptAllWaitingRequests()
  }

  /**
   * remove all participants from the meeting
   */
  fun kickAll() {
    controllerContainer.hostController.kickAll()
  }
}

==> core-android-debug-1.13.2-sources.jar: commonMain/io/dyte/core/models/DyteRoomParticipants.kt <==
package io.dyte.core.models

import io.dyte.core.controllers.IControllerContainer
import io.dyte.core.feat.DyteMeetingParticipant
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.launch
import kotlinx.coroutines.newSingleThreadContext

/**
 * Dyte room participants
 *
 * @property waitlisted A map that contains all the participants waiting to join the meeting.
 * @property joined A list that contains all the participants who have joined the meeting.
 * @property active A map that contains all the participants except the local user who are supposed to be on the screen at the moment
 * @property pinned A map that contains all the pinned participants of the meeting
 *
 * @constructor Create empty Dyte room participants
 */
data class DyteRoomParticipants internal constructor(
  val waitlisted: List<DyteMeetingParticipant>,
  val joined: List<DyteMeetingParticipant>,
  val active: List<DyteMeetingParticipant>,
  val screenshares: List<DyteMeetingParticipant>,
  private val controllerContainer: IControllerContainer
) {

  val  serialScope = CoroutineScope(newSingleThreadContext("DyteRoomParticipants"))
  val pinned: DyteMeetingParticipant?
    get() = controllerContainer.participantController.pinnedParticipant

  val activeSpeaker: DyteMeetingParticipant?
    get() = controllerContainer.participantController.activeSpeaker

  val currentPageNumber : Int
    get() = controllerContainer.participantController.getGridInfo().currentPageNumber

  val canGoNextPage : Boolean
    get() = controllerContainer.participantController.getGridInfo().isNextPagePossible

  val canGoPreviousPage : Boolean
    get() = controllerContainer.participantController.getGridInfo().isPreviousPagePossible

  val pageCount: Int
    get() = controllerContainer.participantController.getGridInfo().pageCount

  fun toMap(): Map<String, Any?> {
    val map = HashMap<String, Any?>()
    map["waitlisted"] = listDyteMeetingParticipantToMap(waitlisted)
    map["joined"] = listDyteMeetingParticipantToMap(joined)
    map["active"] = listDyteMeetingParticipantToMap(active)
    map["screenshares"] = listDyteMeetingParticipantToMap(screenshares)
    map["pinned"] = pinned?.toMap()
    map["activeSpeaker"] = activeSpeaker?.toMap()
    map["grid"] = controllerContainer.participantController.getGridInfo().toMap()
    return map
  }

  private fun listDyteMeetingParticipantToMap(participants: List<DyteMeetingParticipant>): List<Map<String, Any?>> {
    return participants.map { it.toMap() }
  }

  @Throws(Exception::class)
  fun setPage(pageNumber: Int) {
    if (pageNumber < 0) {
      throw IllegalArgumentException("page number cant be negative")
    }
    serialScope.launch {
      controllerContainer.participantController.setPage(pageNumber)
    }
  }

  fun disableAllAudio() {
    // TODO : fix this hardcoding
    serialScope.launch {
      controllerContainer.hostController.muteAllAudio(true)
    }
  }

  @Throws(Exception::class)
  fun disableAllVideo() {
    serialScope.launch {
      controllerContainer.hostController.muteAllVideo()
    }
  }

  @Throws(Exception::class)
  fun acceptAllWaitingRequests() {
    serialScope.launch {
      controllerContainer.waitlistController.acceptAllWaitingRequests()
    }
  }

  /**
   * remove all participants from the meeting
   */
  fun kickAll() {
    serialScope.launch {
      controllerContainer.hostController.kickAll()
    }
  }
}
